"""
Python module generated from Java source file com.google.common.primitives.Booleans

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.primitives import *
from com.google.errorprone.annotations import InlineMe
from java.io import Serializable
from java.util import AbstractList
from java.util import Arrays
from java.util import Collections
from java.util import Comparator
from java.util import RandomAccess
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Booleans:
    """
    Static utility methods pertaining to `boolean` primitives, that are not already found in
    either Boolean or Arrays.
    
    See the Guava User Guide article on <a
    href="https://github.com/google/guava/wiki/PrimitivesExplained">primitive utilities</a>.

    Author(s)
    - Kevin Bourrillion

    Since
    - 1.0
    """

    @staticmethod
    def trueFirst() -> "Comparator"["Boolean"]:
        """
        Returns a `Comparator<Boolean>` that sorts `True` before `False`.
        
        This is particularly useful in Java 8+ in combination with `Comparator.comparing`,
        e.g. `Comparator.comparing(Foo::hasBar, TrueFirst())`.

        Since
        - 21.0
        """
        ...


    @staticmethod
    def falseFirst() -> "Comparator"["Boolean"]:
        """
        Returns a `Comparator<Boolean>` that sorts `False` before `True`.
        
        This is particularly useful in Java 8+ in combination with `Comparator.comparing`,
        e.g. `Comparator.comparing(Foo::hasBar, FalseFirst())`.

        Since
        - 21.0
        """
        ...


    @staticmethod
    def hashCode(value: bool) -> int:
        """
        Returns a hash code for `value`; equal to the result of invoking `((Boolean)
        value).hashCode()`.
        
        **Java 8+ users:** use Boolean.hashCode(boolean) instead.

        Arguments
        - value: a primitive `boolean` value

        Returns
        - a hash code for the value
        """
        ...


    @staticmethod
    def compare(a: bool, b: bool) -> int:
        """
        Compares the two specified `boolean` values in the standard way (`False` is
        considered less than `True`). The sign of the value returned is the same as that of
        `((Boolean) a).compareTo(b)`.
        
        **Note:** this method is now unnecessary and should be treated as deprecated; use the
        equivalent Boolean.compare method instead.

        Arguments
        - a: the first `boolean` to compare
        - b: the second `boolean` to compare

        Returns
        - a positive number if only `a` is `True`, a negative number if only `b` is True, or zero if `a == b`
        """
        ...


    @staticmethod
    def contains(array: list[bool], target: bool) -> bool:
        """
        Returns `True` if `target` is present as an element anywhere in `array`.
        
        **Note:** consider representing the array as a java.util.BitSet instead,
        replacing `Booleans.contains(array, True)` with `!bitSet.isEmpty()` and `Booleans.contains(array, False)` with `bitSet.nextClearBit(0) == sizeOfBitSet`.

        Arguments
        - array: an array of `boolean` values, possibly empty
        - target: a primitive `boolean` value

        Returns
        - `True` if `array[i] == target` for some value of `i`
        """
        ...


    @staticmethod
    def indexOf(array: list[bool], target: bool) -> int:
        """
        Returns the index of the first appearance of the value `target` in `array`.
        
        **Note:** consider representing the array as a java.util.BitSet instead, and
        using java.util.BitSet.nextSetBit(int) or java.util.BitSet.nextClearBit(int).

        Arguments
        - array: an array of `boolean` values, possibly empty
        - target: a primitive `boolean` value

        Returns
        - the least index `i` for which `array[i] == target`, or `-1` if no
            such index exists.
        """
        ...


    @staticmethod
    def indexOf(array: list[bool], target: list[bool]) -> int:
        """
        Returns the start position of the first occurrence of the specified `target` within
        `array`, or `-1` if there is no such occurrence.
        
        More formally, returns the lowest index `i` such that `Arrays.copyOfRange(array,
        i, i + target.length)` contains exactly the same elements as `target`.

        Arguments
        - array: the array to search for the sequence `target`
        - target: the array to search for as a sub-sequence of `array`
        """
        ...


    @staticmethod
    def lastIndexOf(array: list[bool], target: bool) -> int:
        """
        Returns the index of the last appearance of the value `target` in `array`.

        Arguments
        - array: an array of `boolean` values, possibly empty
        - target: a primitive `boolean` value

        Returns
        - the greatest index `i` for which `array[i] == target`, or `-1` if no
            such index exists.
        """
        ...


    @staticmethod
    def concat(*arrays: Tuple[list[bool], ...]) -> list[bool]:
        """
        Returns the values from each provided array combined into a single array. For example, `concat(new boolean[] {a, b`, new boolean[] {}, new boolean[] {c}} returns the array `{a,
        b, c`}.

        Arguments
        - arrays: zero or more `boolean` arrays

        Returns
        - a single array containing all the values from the source arrays, in order

        Raises
        - IllegalArgumentException: if the total number of elements in `arrays` does not fit
            in an `int`
        """
        ...


    @staticmethod
    def ensureCapacity(array: list[bool], minLength: int, padding: int) -> list[bool]:
        """
        Returns an array containing the same values as `array`, but guaranteed to be of a
        specified minimum length. If `array` already has a length of at least `minLength`,
        it is returned directly. Otherwise, a new array of size `minLength + padding` is
        returned, containing the values of `array`, and zeroes in the remaining places.

        Arguments
        - array: the source array
        - minLength: the minimum length the returned array must guarantee
        - padding: an extra amount to "grow" the array by if growth is necessary

        Returns
        - an array containing the values of `array`, with guaranteed minimum length `minLength`

        Raises
        - IllegalArgumentException: if `minLength` or `padding` is negative
        """
        ...


    @staticmethod
    def join(separator: str, *array: Tuple[bool, ...]) -> str:
        """
        Returns a string containing the supplied `boolean` values separated by `separator`.
        For example, `join("-", False, True, False)` returns the string `"False-True-False"`.

        Arguments
        - separator: the text that should appear between consecutive values in the resulting string
            (but not at the start or end)
        - array: an array of `boolean` values, possibly empty
        """
        ...


    @staticmethod
    def lexicographicalComparator() -> "Comparator"[list[bool]]:
        """
        Returns a comparator that compares two `boolean` arrays <a
        href="http://en.wikipedia.org/wiki/Lexicographical_order">lexicographically</a>. That is, it
        compares, using .compare(boolean, boolean)), the first pair of values that follow any
        common prefix, or when one array is a prefix of the other, treats the shorter array as the
        lesser. For example, `[] < [False] < [False, True] < [True]`.
        
        The returned comparator is inconsistent with Object.equals(Object) (since arrays
        support only identity equality), but it is consistent with Arrays.equals(boolean[],
        boolean[]).

        Since
        - 2.0
        """
        ...


    @staticmethod
    def toArray(collection: Iterable["Boolean"]) -> list[bool]:
        """
        Copies a collection of `Boolean` instances into a new array of primitive `boolean`
        values.
        
        Elements are copied from the argument collection as if by `collection.toArray()`.
        Calling this method is as thread-safe as calling that method.
        
        **Note:** consider representing the collection as a java.util.BitSet instead.

        Arguments
        - collection: a collection of `Boolean` objects

        Returns
        - an array containing the same values as `collection`, in the same order, converted
            to primitives

        Raises
        - NullPointerException: if `collection` or any of its elements is null
        """
        ...


    @staticmethod
    def asList(*backingArray: Tuple[bool, ...]) -> list["Boolean"]:
        """
        Returns a fixed-size list backed by the specified array, similar to Arrays.asList(Object[]). The list supports List.set(int, Object), but any attempt to
        set a value to `null` will result in a NullPointerException.
        
        There are at most two distinct objects in this list, `(Boolean) True` and `(Boolean) False`. Java guarantees that those are always represented by the same objects.
        
        The returned list is serializable.

        Arguments
        - backingArray: the array to back the list

        Returns
        - a list view of the array
        """
        ...


    @staticmethod
    def countTrue(*values: Tuple[bool, ...]) -> int:
        """
        Returns the number of `values` that are `True`.

        Since
        - 16.0
        """
        ...


    @staticmethod
    def reverse(array: list[bool]) -> None:
        """
        Reverses the elements of `array`. This is equivalent to `Collections.reverse(Booleans.asList(array))`, but is likely to be more efficient.

        Since
        - 23.1
        """
        ...


    @staticmethod
    def reverse(array: list[bool], fromIndex: int, toIndex: int) -> None:
        """
        Reverses the elements of `array` between `fromIndex` inclusive and `toIndex`
        exclusive. This is equivalent to `Collections.reverse(Booleans.asList(array).subList(fromIndex, toIndex))`, but is likely to be
        more efficient.

        Raises
        - IndexOutOfBoundsException: if `fromIndex < 0`, `toIndex > array.length`, or
            `toIndex > fromIndex`

        Since
        - 23.1
        """
        ...


    @staticmethod
    def rotate(array: list[bool], distance: int) -> None:
        """
        Performs a right rotation of `array` of "distance" places, so that the first element is
        moved to index "distance", and the element at index `i` ends up at index `(distance
        + i) mod array.length`. This is equivalent to `Collections.rotate(Booleans.asList(array),
        distance)`, but is somewhat faster.
        
        The provided "distance" may be negative, which will rotate left.

        Since
        - 32.0.0
        """
        ...


    @staticmethod
    def rotate(array: list[bool], distance: int, fromIndex: int, toIndex: int) -> None:
        """
        Performs a right rotation of `array` between `fromIndex` inclusive and `toIndex` exclusive. This is equivalent to `Collections.rotate(Booleans.asList(array).subList(fromIndex, toIndex), distance)`, but is
        somewhat faster.
        
        The provided "distance" may be negative, which will rotate left.

        Raises
        - IndexOutOfBoundsException: if `fromIndex < 0`, `toIndex > array.length`, or
            `toIndex > fromIndex`

        Since
        - 32.0.0
        """
        ...



"""
Python module generated from Java source file com.google.gson.LongSerializationPolicy

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from enum import Enum
from typing import Any, Callable, Iterable, Tuple


class LongSerializationPolicy(Enum):
    """
    Defines the expected format for a `long` or `Long` type when it is serialized.

    Author(s)
    - Joel Leitch

    Since
    - 1.3
    """

    DEFAULT = 0
    """
    This is the "default" serialization policy that will output a `Long` object as a JSON
    number. For example, assume an object has a long field named "f" then the serialized output
    would be: `{"f":123`}
    
    A `null` value is serialized as JsonNull.
    """
    STRING = 1
    """
    Serializes a long value as a quoted string. For example, assume an object has a long field
    named "f" then the serialized output would be: `{"f":"123"`}
    
    A `null` value is serialized as JsonNull.
    """


    def serialize(self, value: "Long") -> "JsonElement":
        """
        Serialize this `value` using this serialization policy.

        Arguments
        - value: the long value to be serialized into a JsonElement

        Returns
        - the serialized version of `value`
        """
        ...



from .VisibleForTesting import VisibleForTesting
from .J2ktIncompatible import J2ktIncompatible
from .GwtIncompatible import GwtIncompatible
from .GwtCompatible import GwtCompatible
from .Beta import Beta


"""
Python module generated from Java source file org.bukkit.command.CommandExecutor

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.command import *
from typing import Any, Callable, Iterable, Tuple


class CommandExecutor:
    """
    Represents a class which contains a single method for executing commands
    """

    def onCommand(self, sender: "CommandSender", command: "Command", label: str, args: list[str]) -> bool:
        """
        Executes the given command, returning its success.
        
        If False is returned, then the "usage" plugin.yml entry for this command
        (if defined) will be sent to the player.

        Arguments
        - sender: Source of the command
        - command: Command which was executed
        - label: Alias of the command which was used
        - args: Passed command arguments

        Returns
        - True if a valid command, otherwise False
        """
        ...



"""
Python module generated from Java source file com.google.common.io.RecursiveDeleteOption

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from com.google.j2objc.annotations import J2ObjCIncompatible
from enum import Enum
from java.nio.file import SecureDirectoryStream
from typing import Any, Callable, Iterable, Tuple


class RecursiveDeleteOption(Enum):
    """
    Options for use with recursive delete methods (MoreFiles.deleteRecursively and MoreFiles.deleteDirectoryContents).

    Author(s)
    - Colin Decker

    Since
    - 21.0
    """

    ALLOW_INSECURE = 0
    """
    Specifies that the recursive delete should not throw an exception when it can't be guaranteed
    that it can be done securely, without vulnerability to race conditions (i.e. when the file
    system does not support SecureDirectoryStream).
    
    **Warning:** On a file system that supports symbolic links, it is possible for an
    insecure recursive delete to delete files and directories that are *outside* the directory
    being deleted. This can happen if, after checking that a file is a directory (and not a
    symbolic link), that directory is deleted and replaced by a symbolic link to an outside
    directory before the call that opens the directory to read its entries. File systems that
    support `SecureDirectoryStream` do not have this vulnerability.
    """



"""
Python module generated from Java source file com.google.common.collect.RegularImmutableSortedMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from com.google.common.primitives import Ints
from java.util import Comparator
from java.util.function import ObjIntConsumer
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class RegularImmutableSortedMultiset(ImmutableSortedMultiset):
    """
    An immutable sorted multiset with one or more distinct elements.

    Author(s)
    - Louis Wasserman
    """

    def forEachEntry(self, action: "ObjIntConsumer"["E"]) -> None:
        ...


    def firstEntry(self) -> "Entry"["E"]:
        ...


    def lastEntry(self) -> "Entry"["E"]:
        ...


    def count(self, element: "Object") -> int:
        ...


    def size(self) -> int:
        ...


    def elementSet(self) -> "ImmutableSortedSet"["E"]:
        ...


    def headMultiset(self, upperBound: "E", boundType: "BoundType") -> "ImmutableSortedMultiset"["E"]:
        ...


    def tailMultiset(self, lowerBound: "E", boundType: "BoundType") -> "ImmutableSortedMultiset"["E"]:
        ...



"""
Python module generated from Java source file org.bukkit.event.world.PortalCreateEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import World
from org.bukkit.block import BlockState
from org.bukkit.entity import Entity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.world import *
from typing import Any, Callable, Iterable, Tuple


class PortalCreateEvent(WorldEvent, Cancellable):
    """
    Called when a portal is created
    """

    def __init__(self, blocks: list["BlockState"], world: "World", reason: "CreateReason"):
        ...


    def __init__(self, blocks: list["BlockState"], world: "World", entity: "Entity", reason: "CreateReason"):
        ...


    def getBlocks(self) -> list["BlockState"]:
        """
        Gets an array list of all the blocks associated with the created portal

        Returns
        - array list of all the blocks associated with the created portal
        """
        ...


    def getEntity(self) -> "Entity":
        """
        Returns the Entity that triggered this portal creation (if available)

        Returns
        - Entity involved in this event
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getReason(self) -> "CreateReason":
        """
        Gets the reason for the portal's creation

        Returns
        - CreateReason for the portal's creation
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class CreateReason(Enum):
        """
        An enum to specify the various reasons for a portal's creation
        """

        FIRE = 0
        """
        When the blocks inside a portal are created due to a portal frame
        being set on fire.
        """
        NETHER_PAIR = 1
        """
        When a nether portal frame and portal is created at the exit of an
        entered nether portal.
        """
        END_PLATFORM = 2
        """
        When the target end platform is created as a result of a player
        entering an end portal.
        """



"""
Python module generated from Java source file org.bukkit.JukeboxSong

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from org.bukkit.registry import RegistryAware
from typing import Any, Callable, Iterable, Tuple


class JukeboxSong(Keyed, Translatable, RegistryAware):
    """
    Represents a song which may play in a Jukebox.
    """

    THIRTEEN = get("13")
    CAT = get("cat")
    BLOCKS = get("blocks")
    CHIRP = get("chirp")
    FAR = get("far")
    MALL = get("mall")
    MELLOHI = get("mellohi")
    STAL = get("stal")
    STRAD = get("strad")
    WARD = get("ward")
    ELEVEN = get("11")
    WAIT = get("wait")
    PIGSTEP = get("pigstep")
    OTHERSIDE = get("otherside")
    FIVE = get("5")
    RELIC = get("relic")
    PRECIPICE = get("precipice")
    CREATOR = get("creator")
    CREATOR_MUSIC_BOX = get("creator_music_box")


    @staticmethod
    def get(key: str) -> "JukeboxSong":
        ...


    def getKey(self) -> "NamespacedKey":
        """
        See
        - .isRegistered()

        Deprecated
        - A key might not always be present, use .getKeyOrThrow() instead.
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.GlowSquid

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class GlowSquid(Squid):
    """
    A Glow Squid.
    """

    def getDarkTicksRemaining(self) -> int:
        """
        Get the number of dark ticks remaining for this squid.
        
        Bravo Six will go dark for 100 ticks (5 seconds) if damaged.

        Returns
        - dark ticks remaining
        """
        ...


    def setDarkTicksRemaining(self, darkTicksRemaining: int) -> None:
        """
        Sets the number of dark ticks remaining for this squid.
        
        Bravo Six will go dark for 100 ticks (5 seconds) if damaged.

        Arguments
        - darkTicksRemaining: dark ticks remaining
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.constructor.SafeConstructor

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.math import BigInteger
from java.util import Calendar
from java.util import Iterator
from java.util import TimeZone
from java.util.regex import Matcher
from java.util.regex import Pattern
from org.yaml.snakeyaml import LoaderOptions
from org.yaml.snakeyaml.constructor import *
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.external.biz.base64Coder import Base64Coder
from org.yaml.snakeyaml.nodes import MappingNode
from org.yaml.snakeyaml.nodes import Node
from org.yaml.snakeyaml.nodes import NodeId
from org.yaml.snakeyaml.nodes import NodeTuple
from org.yaml.snakeyaml.nodes import ScalarNode
from org.yaml.snakeyaml.nodes import SequenceNode
from org.yaml.snakeyaml.nodes import Tag
from typing import Any, Callable, Iterable, Tuple


class SafeConstructor(BaseConstructor):
    """
    Construct standard Java classes
    """

    undefinedConstructor = ConstructUndefined()


    def __init__(self, loaderOptions: "LoaderOptions"):
        """
        Create an instance

        Arguments
        - loaderOptions: - the configuration options
        """
        ...


    class ConstructYamlNull(AbstractConstruct):

        def construct(self, node: "Node") -> "Object":
            ...


    class ConstructYamlBool(AbstractConstruct):

        def construct(self, node: "Node") -> "Object":
            ...


    class ConstructYamlInt(AbstractConstruct):

        def construct(self, node: "Node") -> "Object":
            ...


    class ConstructYamlFloat(AbstractConstruct):

        def construct(self, node: "Node") -> "Object":
            ...


    class ConstructYamlBinary(AbstractConstruct):

        def construct(self, node: "Node") -> "Object":
            ...


    class ConstructYamlTimestamp(AbstractConstruct):

        def getCalendar(self) -> "Calendar":
            ...


        def construct(self, node: "Node") -> "Object":
            ...


    class ConstructYamlOmap(AbstractConstruct):

        def construct(self, node: "Node") -> "Object":
            ...


    class ConstructYamlPairs(AbstractConstruct):

        def construct(self, node: "Node") -> "Object":
            ...


    class ConstructYamlSet(Construct):

        def construct(self, node: "Node") -> "Object":
            ...


        def construct2ndStep(self, node: "Node", object: "Object") -> None:
            ...


    class ConstructYamlStr(AbstractConstruct):

        def construct(self, node: "Node") -> "Object":
            ...


    class ConstructYamlSeq(Construct):

        def construct(self, node: "Node") -> "Object":
            ...


        def construct2ndStep(self, node: "Node", data: "Object") -> None:
            ...


    class ConstructYamlMap(Construct):

        def construct(self, node: "Node") -> "Object":
            ...


        def construct2ndStep(self, node: "Node", object: "Object") -> None:
            ...


    class ConstructUndefined(AbstractConstruct):

        def construct(self, node: "Node") -> "Object":
            ...



"""
Python module generated from Java source file com.google.common.io.CountingOutputStream

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from java.io import FilterOutputStream
from java.io import IOException
from java.io import OutputStream
from typing import Any, Callable, Iterable, Tuple


class CountingOutputStream(FilterOutputStream):
    """
    An OutputStream that counts the number of bytes written.

    Author(s)
    - Chris Nokleberg

    Since
    - 1.0
    """

    def __init__(self, out: "OutputStream"):
        """
        Wraps another output stream, counting the number of bytes written.

        Arguments
        - out: the output stream to be wrapped
        """
        ...


    def getCount(self) -> int:
        """
        Returns the number of bytes written.
        """
        ...


    def write(self, b: list[int], off: int, len: int) -> None:
        ...


    def write(self, b: int) -> None:
        ...


    def close(self) -> None:
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from com.google.errorprone.annotations import DoNotMock
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import RetainedWith
from com.google.j2objc.annotations import WeakOuter
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.util import Arrays
from java.util import BitSet
from java.util import Collections
from java.util import Comparator
from java.util import EnumMap
from java.util import Iterator
from java.util import SortedMap
from java.util import Spliterator
from java.util.function import BiFunction
from java.util.function import BinaryOperator
from java.util.function import Function
from java.util.stream import Collector
from java.util.stream import Collectors
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableMap(Map, Serializable):
    """
    A Map whose contents will never change, with many other important properties detailed at
    ImmutableCollection.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/ImmutableCollectionsExplained">immutable collections</a>.

    Author(s)
    - Kevin Bourrillion

    Since
    - 2.0
    """

    @staticmethod
    def toImmutableMap(keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"]) -> "Collector"["T", Any, "ImmutableMap"["K", "V"]]:
        """
        Returns a Collector that accumulates elements into an `ImmutableMap` whose keys
        and values are the result of applying the provided mapping functions to the input elements.
        Entries appear in the result `ImmutableMap` in encounter order.
        
        If the mapped keys contain duplicates (according to Object.equals(Object), an `IllegalArgumentException` is thrown when the collection operation is performed. (This differs
        from the `Collector` returned by Collectors.toMap(Function, Function), which
        throws an `IllegalStateException`.)

        Since
        - 21.0
        """
        ...


    @staticmethod
    def toImmutableMap(keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"], mergeFunction: "BinaryOperator"["V"]) -> "Collector"["T", Any, "ImmutableMap"["K", "V"]]:
        """
        Returns a Collector that accumulates elements into an `ImmutableMap` whose keys
        and values are the result of applying the provided mapping functions to the input elements.
        
        If the mapped keys contain duplicates (according to Object.equals(Object)), the
        values are merged using the specified merging function. If the merging function returns `null`, then the collector removes the value that has been computed for the key thus far (though
        future occurrences of the key would reinsert it).
        
        Entries will appear in the encounter order of the first occurrence of the key.

        Since
        - 21.0
        """
        ...


    @staticmethod
    def of() -> "ImmutableMap"["K", "V"]:
        """
        Returns the empty map. This map behaves and performs comparably to Collections.emptyMap, and is preferable mainly for consistency and maintainability of your
        code.
        
        **Performance note:** the instance returned is a singleton.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V") -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing a single entry. This map behaves and performs comparably to
        Collections.singletonMap but will not accept a null key or value. It is preferable
        mainly for consistency and maintainability of your code.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V") -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, in order.

        Raises
        - IllegalArgumentException: if duplicate keys are provided
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V") -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, in order.

        Raises
        - IllegalArgumentException: if duplicate keys are provided
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V") -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, in order.

        Raises
        - IllegalArgumentException: if duplicate keys are provided
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V") -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, in order.

        Raises
        - IllegalArgumentException: if duplicate keys are provided
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V") -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, in order.

        Raises
        - IllegalArgumentException: if duplicate keys are provided

        Since
        - 31.0
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V") -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, in order.

        Raises
        - IllegalArgumentException: if duplicate keys are provided

        Since
        - 31.0
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V") -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, in order.

        Raises
        - IllegalArgumentException: if duplicate keys are provided

        Since
        - 31.0
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V", k9: "K", v9: "V") -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, in order.

        Raises
        - IllegalArgumentException: if duplicate keys are provided

        Since
        - 31.0
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V", k9: "K", v9: "V", k10: "K", v10: "V") -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, in order.

        Raises
        - IllegalArgumentException: if duplicate keys are provided

        Since
        - 31.0
        """
        ...


    @staticmethod
    def ofEntries(*entries: Tuple["Entry"["K", "V"], ...]) -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, in order.

        Raises
        - IllegalArgumentException: if duplicate keys are provided

        Since
        - 31.0
        """
        ...


    @staticmethod
    def builder() -> "Builder"["K", "V"]:
        """
        Returns a new builder. The generated builder is equivalent to the builder created by the Builder constructor.
        """
        ...


    @staticmethod
    def builderWithExpectedSize(expectedSize: int) -> "Builder"["K", "V"]:
        """
        Returns a new builder, expecting the specified number of entries to be added.
        
        If `expectedSize` is exactly the number of entries added to the builder before Builder.build is called, the builder is likely to perform better than an unsized .builder() would have.
        
        It is not specified if any performance benefits apply if `expectedSize` is close to,
        but not exactly, the number of entries added to the builder.

        Since
        - 23.1
        """
        ...


    @staticmethod
    def copyOf(map: dict["K", "V"]) -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the same entries as `map`. The returned map iterates
        over entries in the same order as the `entrySet` of the original map. If `map`
        somehow contains entries with duplicate keys (for example, if it is a `SortedMap` whose
        comparator is not *consistent with equals*), the results of this method are undefined.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.

        Raises
        - NullPointerException: if any key or value in `map` is null
        """
        ...


    @staticmethod
    def copyOf(entries: Iterable["Entry"["K", "V"]]) -> "ImmutableMap"["K", "V"]:
        """
        Returns an immutable map containing the specified entries. The returned map iterates over
        entries in the same order as the original iterable.

        Raises
        - NullPointerException: if any key, value, or entry is null
        - IllegalArgumentException: if two entries have the same key

        Since
        - 19.0
        """
        ...


    def put(self, k: "K", v: "V") -> "V":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def putIfAbsent(self, key: "K", value: "V") -> "V":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def replace(self, key: "K", oldValue: "V", newValue: "V") -> bool:
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def replace(self, key: "K", value: "V") -> "V":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def computeIfAbsent(self, key: "K", mappingFunction: "Function"["K", "V"]) -> "V":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def computeIfPresent(self, key: "K", remappingFunction: "BiFunction"["K", "V", "V"]) -> "V":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def compute(self, key: "K", remappingFunction: "BiFunction"["K", "V", "V"]) -> "V":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def merge(self, key: "K", value: "V", function: "BiFunction"["V", "V", "V"]) -> "V":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def putAll(self, map: dict["K", "V"]) -> None:
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def replaceAll(self, function: "BiFunction"["K", "V", "V"]) -> None:
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def remove(self, o: "Object") -> "V":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def remove(self, key: "Object", value: "Object") -> bool:
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def clear(self) -> None:
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def isEmpty(self) -> bool:
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def containsValue(self, value: "Object") -> bool:
        ...


    def get(self, key: "Object") -> "V":
        ...


    def getOrDefault(self, key: "Object", defaultValue: "V") -> "V":
        """
        Since
        - 21.0 (but only since 23.5 in the Android <a
            href="https://github.com/google/guava#guava-google-core-libraries-for-java">flavor</a>).
            Note, however, that Java 8+ users can call this method with any version and flavor of
            Guava.
        """
        ...


    def entrySet(self) -> "ImmutableSet"["Entry"["K", "V"]]:
        """
        Returns an immutable set of the mappings in this map. The iteration order is specified by the
        method used to create this map. Typically, this is insertion order.
        """
        ...


    def keySet(self) -> "ImmutableSet"["K"]:
        """
        Returns an immutable set of the keys in this map, in the same order that they appear in .entrySet.
        """
        ...


    def values(self) -> "ImmutableCollection"["V"]:
        """
        Returns an immutable collection of the values in this map, in the same order that they appear
        in .entrySet.
        """
        ...


    def asMultimap(self) -> "ImmutableSetMultimap"["K", "V"]:
        """
        Returns a multimap view of the map.

        Since
        - 14.0
        """
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        ...


    class Builder:
        """
        A builder for creating immutable map instances, especially `public static final` maps
        ("constant maps"). Example:
        
        ````static final ImmutableMap<String, Integer> WORD_TO_INT =
            new ImmutableMap.Builder<String, Integer>()
                .put("one", 1)
                .put("two", 2)
                .put("three", 3)
                .buildOrThrow();````
        
        For *small* immutable maps, the `ImmutableMap.of()` methods are even more
        convenient.
        
        By default, a `Builder` will generate maps that iterate over entries in the order they
        were inserted into the builder, equivalently to `LinkedHashMap`. For example, in the
        above example, `WORD_TO_INT.entrySet()` is guaranteed to iterate over the entries in the
        order `"one"=1, "two"=2, "three"=3`, and `keySet()` and `values()` respect
        the same order. If you want a different order, consider using ImmutableSortedMap to
        sort by keys, or call .orderEntriesByValue(Comparator), which changes this builder to
        sort entries by value.
        
        Builder instances can be reused - it is safe to call .buildOrThrow multiple times to
        build multiple maps in series. Each map is a superset of the maps created before it.

        Since
        - 2.0
        """

        def __init__(self):
            """
            Creates a new builder. The returned builder is equivalent to the builder generated by ImmutableMap.builder.
            """
            ...


        def put(self, key: "K", value: "V") -> "Builder"["K", "V"]:
            """
            Associates `key` with `value` in the built map. If the same key is put more than
            once, .buildOrThrow will fail, while .buildKeepingLast will keep the last
            value put for that key.
            """
            ...


        def put(self, entry: "Entry"["K", "V"]) -> "Builder"["K", "V"]:
            """
            Adds the given `entry` to the map, making it immutable if necessary. If the same key is
            put more than once, .buildOrThrow will fail, while .buildKeepingLast will
            keep the last value put for that key.

            Since
            - 11.0
            """
            ...


        def putAll(self, map: dict["K", "V"]) -> "Builder"["K", "V"]:
            """
            Associates all of the given map's keys and values in the built map. If the same key is put
            more than once, .buildOrThrow will fail, while .buildKeepingLast will keep
            the last value put for that key.

            Raises
            - NullPointerException: if any key or value in `map` is null
            """
            ...


        def putAll(self, entries: Iterable["Entry"["K", "V"]]) -> "Builder"["K", "V"]:
            """
            Adds all of the given entries to the built map. If the same key is put more than once, .buildOrThrow will fail, while .buildKeepingLast will keep the last value put for
            that key.

            Raises
            - NullPointerException: if any key, value, or entry is null

            Since
            - 19.0
            """
            ...


        def orderEntriesByValue(self, valueComparator: "Comparator"["V"]) -> "Builder"["K", "V"]:
            """
            Configures this `Builder` to order entries by value according to the specified
            comparator.
            
            The sort order is stable, that is, if two entries have values that compare as equivalent,
            the entry that was inserted first will be first in the built map's iteration order.

            Raises
            - IllegalStateException: if this method was already called

            Since
            - 19.0
            """
            ...


        def build(self) -> "ImmutableMap"["K", "V"]:
            """
            Returns a newly-created immutable map. The iteration order of the returned map is the order
            in which entries were inserted into the builder, unless .orderEntriesByValue was
            called, in which case entries are sorted by value.
            
            Prefer the equivalent method .buildOrThrow() to make it explicit that the method
            will throw an exception if there are duplicate keys. The `build()` method will soon be
            deprecated.

            Raises
            - IllegalArgumentException: if duplicate keys were added
            """
            ...


        def buildOrThrow(self) -> "ImmutableMap"["K", "V"]:
            """
            Returns a newly-created immutable map, or throws an exception if any key was added more than
            once. The iteration order of the returned map is the order in which entries were inserted
            into the builder, unless .orderEntriesByValue was called, in which case entries are
            sorted by value.

            Raises
            - IllegalArgumentException: if duplicate keys were added

            Since
            - 31.0
            """
            ...


        def buildKeepingLast(self) -> "ImmutableMap"["K", "V"]:
            """
            Returns a newly-created immutable map, using the last value for any key that was added more
            than once. The iteration order of the returned map is the order in which entries were
            inserted into the builder, unless .orderEntriesByValue was called, in which case
            entries are sorted by value. If a key was added more than once, it appears in iteration order
            based on the first time it was added, again unless .orderEntriesByValue was called.
            
            In the current implementation, all values associated with a given key are stored in the
            `Builder` object, even though only one of them will be used in the built map. If there
            can be many repeated keys, it may be more space-efficient to use a java.util.LinkedHashMap LinkedHashMap and ImmutableMap.copyOf(Map) rather than
            `ImmutableMap.Builder`.

            Since
            - 31.1
            """
            ...



"""
Python module generated from Java source file org.joml.Runtime

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.text import NumberFormat
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class Runtime:
    """
    Internal class to detect features of the runtime.

    Author(s)
    - Kai Burjack
    """

    HAS_floatToRawIntBits = hasFloatToRawIntBits()
    HAS_doubleToRawLongBits = hasDoubleToRawLongBits()
    HAS_Long_rotateLeft = hasLongRotateLeft()
    HAS_Math_fma = Options.USE_MATH_FMA && hasMathFma()


    @staticmethod
    def floatToIntBits(flt: float) -> int:
        ...


    @staticmethod
    def doubleToLongBits(dbl: float) -> int:
        ...


    @staticmethod
    def formatNumbers(str: str) -> str:
        ...


    @staticmethod
    def format(number: float, format: "NumberFormat") -> str:
        ...


    @staticmethod
    def equals(a: float, b: float, delta: float) -> bool:
        ...


    @staticmethod
    def equals(a: float, b: float, delta: float) -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.entity.AbstractHorse

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from org.bukkit.inventory import AbstractHorseInventory
from org.bukkit.inventory import InventoryHolder
from typing import Any, Callable, Iterable, Tuple


class AbstractHorse(Vehicle, InventoryHolder, Tameable):
    """
    Represents a Horse-like creature.
    """

    def getVariant(self) -> "Horse.Variant":
        """
        Gets the horse's variant.
        
        A horse's variant defines its physical appearance and capabilities.
        Whether a horse is a regular horse, donkey, mule, or other kind of horse
        is determined using the variant.

        Returns
        - a Horse.Variant representing the horse's variant

        Deprecated
        - different variants are different classes
        """
        ...


    def setVariant(self, variant: "Horse.Variant") -> None:
        """
        Arguments
        - variant: variant

        Deprecated
        - you are required to spawn a different entity
        """
        ...


    def getDomestication(self) -> int:
        """
        Gets the domestication level of this horse.
        
        A higher domestication level indicates that the horse is closer to
        becoming tame. As the domestication level gets closer to the max
        domestication level, the chance of the horse becoming tame increases.

        Returns
        - domestication level
        """
        ...


    def setDomestication(self, level: int) -> None:
        """
        Sets the domestication level of this horse.
        
        Setting the domestication level to a high value will increase the
        horse's chances of becoming tame.
        
        Domestication level must be greater than zero and no greater than
        the max domestication level of the horse, determined with
        .getMaxDomestication()

        Arguments
        - level: domestication level
        """
        ...


    def getMaxDomestication(self) -> int:
        """
        Gets the maximum domestication level of this horse.
        
        The higher this level is, the longer it will likely take
        for the horse to be tamed.

        Returns
        - the max domestication level
        """
        ...


    def setMaxDomestication(self, level: int) -> None:
        """
        Sets the maximum domestication level of this horse.
        
        Setting a higher max domestication will increase the amount of
        domesticating (feeding, riding, etc.) necessary in order to tame it,
        while setting a lower max value will have the opposite effect.
        
        Maximum domestication must be greater than zero.

        Arguments
        - level: the max domestication level
        """
        ...


    def getJumpStrength(self) -> float:
        """
        Gets the jump strength of this horse.
        
        Jump strength defines how high the horse can jump. A higher jump strength
        increases how high a jump will go.

        Returns
        - the horse's jump strength
        """
        ...


    def setJumpStrength(self, strength: float) -> None:
        """
        Sets the jump strength of this horse.
        
        A higher jump strength increases how high a jump will go.
        Setting a jump strength to 0 will result in no jump.
        You cannot set a jump strength to a value below 0 or
        above 2.

        Arguments
        - strength: jump strength for this horse
        """
        ...


    def isEatingHaystack(self) -> bool:
        """
        Gets whether the horse is currently grazing hay.

        Returns
        - True if eating hay
        """
        ...


    def setEatingHaystack(self, eatingHaystack: bool) -> None:
        """
        Sets whether the horse is grazing hay.

        Arguments
        - eatingHaystack: new hay grazing status
        """
        ...


    def getInventory(self) -> "AbstractHorseInventory":
        ...



"""
Python module generated from Java source file org.bukkit.material.TexturedMaterial

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class TexturedMaterial(MaterialData):
    """
    Represents textured materials like steps and smooth bricks

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self, m: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def getTextures(self) -> list["Material"]:
        """
        Retrieve a list of possible textures. The first element of the list
        will be used as a default.

        Returns
        - a list of possible textures for this block
        """
        ...


    def getMaterial(self) -> "Material":
        """
        Gets the current Material this block is made of

        Returns
        - Material of this block
        """
        ...


    def setMaterial(self, material: "Material") -> None:
        """
        Sets the material this block is made of

        Arguments
        - material: New material of this block
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "TexturedMaterial":
        ...



"""
Python module generated from Java source file org.bukkit.block.DecoratedPot

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import Material
from org.bukkit import Tag
from org.bukkit.block import *
from org.bukkit.inventory import BlockInventoryHolder
from org.bukkit.inventory import DecoratedPotInventory
from typing import Any, Callable, Iterable, Tuple


class DecoratedPot(TileState, BlockInventoryHolder):
    """
    Represents a captured state of a decorated pot.
    """

    def setSherd(self, side: "Side", sherd: "Material") -> None:
        """
        Set the sherd on the provided side.

        Arguments
        - side: the side to set
        - sherd: the sherd, or null to set a blank side.

        Raises
        - IllegalArgumentException: if the sherd is not either
        tagged by Tag.ITEMS_DECORATED_POT_SHERDS, Material.BRICK,
        or `null`
        """
        ...


    def getSherd(self, side: "Side") -> "Material":
        """
        Get the sherd on the provided side.

        Arguments
        - side: the side to get

        Returns
        - the sherd on the side or Material.BRICK if it's blank
        """
        ...


    def getSherds(self) -> dict["Side", "Material"]:
        """
        Gets a Map of all sides on this decorated pot and the sherds on them.
        If a side does not have a specific sherd on it, Material.BRICK
        will be the value of that side.

        Returns
        - the sherds
        """
        ...


    def getShards(self) -> list["Material"]:
        """
        Gets the sherds on this decorated pot. For faces without a specific sherd,
        Material.BRICK is used in its place.

        Returns
        - the sherds

        Deprecated
        - in favor of .getSherds()
        """
        ...


    def getInventory(self) -> "DecoratedPotInventory":
        """
        Returns
        - inventory

        See
        - Container.getInventory()
        """
        ...


    def getSnapshotInventory(self) -> "DecoratedPotInventory":
        """
        Returns
        - snapshot inventory

        See
        - Container.getSnapshotInventory()
        """
        ...


    class Side(Enum):
        """
        A side on a decorated pot. Sides are relative to the facing state of a
        org.bukkit.block.data.type.DecoratedPot.
        """

        BACK = 0
        LEFT = 1
        RIGHT = 2
        FRONT = 3



"""
Python module generated from Java source file org.bukkit.command.CommandMap

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.command import *
from typing import Any, Callable, Iterable, Tuple


class CommandMap:

    def registerAll(self, fallbackPrefix: str, commands: list["Command"]) -> None:
        """
        Registers all the commands belonging to a certain plugin.
        
        Caller can use:-
        
        - command.getName() to determine the label registered for this
            command
        - command.getAliases() to determine the aliases which where
            registered

        Arguments
        - fallbackPrefix: a prefix which is prepended to each command with
            a ':' one or more times to make the command unique
        - commands: a list of commands to register
        """
        ...


    def register(self, label: str, fallbackPrefix: str, command: "Command") -> bool:
        """
        Registers a command. Returns True on success; False if name is already
        taken and fallback had to be used.
        
        Caller can use:-
        
        - command.getName() to determine the label registered for this
            command
        - command.getAliases() to determine the aliases which where
            registered

        Arguments
        - label: the label of the command, without the '/'-prefix.
        - fallbackPrefix: a prefix which is prepended to the command with a
            ':' one or more times to make the command unique
        - command: the command to register

        Returns
        - True if command was registered with the passed in label, False
            otherwise, which indicates the fallbackPrefix was used one or more
            times
        """
        ...


    def register(self, fallbackPrefix: str, command: "Command") -> bool:
        """
        Registers a command. Returns True on success; False if name is already
        taken and fallback had to be used.
        
        Caller can use:-
        
        - command.getName() to determine the label registered for this
            command
        - command.getAliases() to determine the aliases which where
            registered

        Arguments
        - fallbackPrefix: a prefix which is prepended to the command with a
            ':' one or more times to make the command unique
        - command: the command to register, from which label is determined
            from the command name

        Returns
        - True if command was registered with the passed in label, False
            otherwise, which indicates the fallbackPrefix was used one or more
            times
        """
        ...


    def dispatch(self, sender: "CommandSender", cmdLine: str) -> bool:
        """
        Looks for the requested command and executes it if found.

        Arguments
        - sender: The command's sender
        - cmdLine: command + arguments. Example: "/test abc 123"

        Returns
        - returns False if no target is found, True otherwise.

        Raises
        - CommandException: Thrown when the executor for the given command
            fails with an unhandled exception
        """
        ...


    def clearCommands(self) -> None:
        """
        Clears all registered commands.
        """
        ...


    def getCommand(self, name: str) -> "Command":
        """
        Gets the command registered to the specified name

        Arguments
        - name: Name of the command to retrieve

        Returns
        - Command with the specified name or null if a command with that
            label doesn't exist
        """
        ...


    def tabComplete(self, sender: "CommandSender", cmdLine: str) -> list[str]:
        """
        Looks for the requested command and executes an appropriate
        tab-completer if found. This method will also tab-complete partial
        commands.

        Arguments
        - sender: The command's sender.
        - cmdLine: The entire command string to tab-complete, excluding
            initial slash.

        Returns
        - a list of possible tab-completions. This list may be immutable.
            Will be null if no matching command of which sender has permission.

        Raises
        - CommandException: Thrown when the tab-completer for the given
            command fails with an unhandled exception
        - IllegalArgumentException: if either sender or cmdLine are null
        """
        ...


    def tabComplete(self, sender: "CommandSender", cmdLine: str, location: "Location") -> list[str]:
        """
        Looks for the requested command and executes an appropriate
        tab-completer if found. This method will also tab-complete partial
        commands.

        Arguments
        - sender: The command's sender.
        - cmdLine: The entire command string to tab-complete, excluding
            initial slash.
        - location: The position looked at by the sender, or null if none

        Returns
        - a list of possible tab-completions. This list may be immutable.
            Will be null if no matching command of which sender has permission.

        Raises
        - CommandException: Thrown when the tab-completer for the given
            command fails with an unhandled exception
        - IllegalArgumentException: if either sender or cmdLine are null
        """
        ...



"""
Python module generated from Java source file org.bukkit.material.Diode

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Diode(MaterialData, Directional, Redstone):
    """
    Represents a diode/repeater in the on or off state, with a delay and facing
    in a specific direction.

    See
    - Material.LEGACY_DIODE_BLOCK_ON

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        """
        Constructs a diode switched on, with a delay of 1 and facing the default
        direction (north).
        
        By default this constructor creates a diode that is switched on for
        backwards compatibility with past implementations.
        """
        ...


    def __init__(self, facingDirection: "BlockFace"):
        """
        Constructs a diode switched off, with a delay of 1 and facing the
        specified direction.

        Arguments
        - facingDirection: the direction the diode is facing

        See
        - BlockFace
        """
        ...


    def __init__(self, facingDirection: "BlockFace", delay: int):
        """
        Constructs a diode switched off, with the specified delay and facing the
        specified direction.

        Arguments
        - facingDirection: the direction the diode is facing
        - delay: The number of ticks (1-4) before the diode turns on after
        being powered

        See
        - BlockFace
        """
        ...


    def __init__(self, facingDirection: "BlockFace", delay: int, state: bool):
        """
        Constructs a diode switched on or off, with the specified delay and
        facing the specified direction.

        Arguments
        - facingDirection: the direction the diode is facing
        - delay: The number of ticks (1-4) before the diode turns on after
        being powered
        - state: True if the diode is in the on state

        See
        - BlockFace
        """
        ...


    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def setDelay(self, delay: int) -> None:
        """
        Sets the delay of the repeater.

        Arguments
        - delay: The new delay (1-4)
        """
        ...


    def getDelay(self) -> int:
        """
        Gets the delay of the repeater in ticks.

        Returns
        - The delay (1-4)
        """
        ...


    def setFacingDirection(self, face: "BlockFace") -> None:
        """
        Sets the direction this diode is facing.

        Arguments
        - face: The direction to set this diode to

        See
        - BlockFace
        """
        ...


    def getFacing(self) -> "BlockFace":
        """
        Gets the direction this diode is facing

        Returns
        - The direction this diode is facing

        See
        - BlockFace
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "Diode":
        ...


    def isPowered(self) -> bool:
        """
        Checks if the diode is powered.

        Returns
        - True if the diode is powered
        """
        ...



"""
Python module generated from Java source file java.lang.ref.WeakReference

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.ref import *
from typing import Any, Callable, Iterable, Tuple


class WeakReference(Reference):

    def __init__(self, referent: "T"):
        """
        Creates a new weak reference that refers to the given object.  The new
        reference is not registered with any queue.

        Arguments
        - referent: object the new weak reference will refer to
        """
        ...


    def __init__(self, referent: "T", q: "ReferenceQueue"["T"]):
        """
        Creates a new weak reference that refers to the given object and is
        registered with the given queue.

        Arguments
        - referent: object the new weak reference will refer to
        - q: the queue with which the reference is to be registered,
                 or `null` if registration is not required
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.introspector.FieldProperty

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.reflect import Field
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.introspector import *
from org.yaml.snakeyaml.util import ArrayUtils
from typing import Any, Callable, Iterable, Tuple


class FieldProperty(GenericProperty):
    """
    
    A `FieldProperty` is a `Property` which is accessed as a field, without
    going through accessor methods (setX, getX). The field may have any scope (public, package,
    protected, private).
    """

    def __init__(self, field: "Field"):
        ...


    def set(self, object: "Object", value: "Object") -> None:
        ...


    def get(self, object: "Object") -> "Object":
        ...


    def getAnnotations(self) -> list["Annotation"]:
        ...


    def getAnnotation(self, annotationType: type["A"]) -> "A":
        ...



"""
Python module generated from Java source file org.bukkit.damage.DamageType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit import Translatable
from org.bukkit.damage import *
from org.bukkit.registry import RegistryAware
from typing import Any, Callable, Iterable, Tuple


class DamageType(Keyed, Translatable, RegistryAware):
    """
    Represent a type of damage that an entity can receive.
    
    Constants in this class include the base types provided by the vanilla
    server. Data packs are capable of registering more types of damage which may
    be obtained through the Registry.DAMAGE_TYPE.

    See
    - <a href="https://minecraft.wiki/w/Damage_type">Minecraft Wiki</a>
    """

    IN_FIRE = getDamageType("in_fire")
    CAMPFIRE = getDamageType("campfire")
    LIGHTNING_BOLT = getDamageType("lightning_bolt")
    ON_FIRE = getDamageType("on_fire")
    LAVA = getDamageType("lava")
    HOT_FLOOR = getDamageType("hot_floor")
    IN_WALL = getDamageType("in_wall")
    CRAMMING = getDamageType("cramming")
    DROWN = getDamageType("drown")
    STARVE = getDamageType("starve")
    CACTUS = getDamageType("cactus")
    FALL = getDamageType("fall")
    ENDER_PEARL = getDamageType("ender_pearl")
    FLY_INTO_WALL = getDamageType("fly_into_wall")
    OUT_OF_WORLD = getDamageType("out_of_world")
    GENERIC = getDamageType("generic")
    MAGIC = getDamageType("magic")
    WITHER = getDamageType("wither")
    DRAGON_BREATH = getDamageType("dragon_breath")
    DRY_OUT = getDamageType("dry_out")
    SWEET_BERRY_BUSH = getDamageType("sweet_berry_bush")
    FREEZE = getDamageType("freeze")
    STALAGMITE = getDamageType("stalagmite")
    FALLING_BLOCK = getDamageType("falling_block")
    FALLING_ANVIL = getDamageType("falling_anvil")
    FALLING_STALACTITE = getDamageType("falling_stalactite")
    STING = getDamageType("sting")
    MOB_ATTACK = getDamageType("mob_attack")
    MOB_ATTACK_NO_AGGRO = getDamageType("mob_attack_no_aggro")
    PLAYER_ATTACK = getDamageType("player_attack")
    ARROW = getDamageType("arrow")
    TRIDENT = getDamageType("trident")
    MOB_PROJECTILE = getDamageType("mob_projectile")
    SPIT = getDamageType("spit")
    FIREWORKS = getDamageType("fireworks")
    FIREBALL = getDamageType("fireball")
    UNATTRIBUTED_FIREBALL = getDamageType("unattributed_fireball")
    WITHER_SKULL = getDamageType("wither_skull")
    THROWN = getDamageType("thrown")
    INDIRECT_MAGIC = getDamageType("indirect_magic")
    THORNS = getDamageType("thorns")
    EXPLOSION = getDamageType("explosion")
    PLAYER_EXPLOSION = getDamageType("player_explosion")
    SONIC_BOOM = getDamageType("sonic_boom")
    BAD_RESPAWN_POINT = getDamageType("bad_respawn_point")
    OUTSIDE_BORDER = getDamageType("outside_border")
    GENERIC_KILL = getDamageType("generic_kill")
    WIND_CHARGE = getDamageType("wind_charge")
    MACE_SMASH = getDamageType("mace_smash")


    @staticmethod
    def getDamageType(key: str) -> "DamageType":
        ...


    def getTranslationKey(self) -> str:
        """
        
        
        The returned key is that of the death message sent when this damage type
        is responsible for the death of an entity.
        
        <strong>Note</strong> This translation key is only used if
        .getDeathMessageType() is DeathMessageType.DEFAULT
        """
        ...


    def getDamageScaling(self) -> "DamageScaling":
        """
        Get the DamageScaling for this damage type.

        Returns
        - the damage scaling
        """
        ...


    def getDamageEffect(self) -> "DamageEffect":
        """
        Get the DamageEffect for this damage type.

        Returns
        - the damage effect
        """
        ...


    def getDeathMessageType(self) -> "DeathMessageType":
        """
        Get the DeathMessageType for this damage type.

        Returns
        - the death message type
        """
        ...


    def getExhaustion(self) -> float:
        """
        Get the amount of hunger exhaustion caused by this damage type.

        Returns
        - the exhaustion
        """
        ...


    def getKey(self) -> "NamespacedKey":
        """
        See
        - .isRegistered()

        Deprecated
        - A key might not always be present, use .getKeyOrThrow() instead.
        """
        ...



"""
Python module generated from Java source file com.google.gson.internal.Primitives

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import *
from java.lang.reflect import Type
from typing import Any, Callable, Iterable, Tuple


class Primitives:
    """
    Contains static utility methods pertaining to primitive types and their corresponding wrapper
    types.

    Author(s)
    - Kevin Bourrillion
    """

    @staticmethod
    def isPrimitive(type: "Type") -> bool:
        """
        Returns True if this type is a primitive.
        """
        ...


    @staticmethod
    def isWrapperType(type: "Type") -> bool:
        """
        Returns `True` if `type` is one of the nine primitive-wrapper types, such as Integer.

        See
        - Class.isPrimitive
        """
        ...


    @staticmethod
    def wrap(type: type["T"]) -> type["T"]:
        """
        Returns the corresponding wrapper type of `type` if it is a primitive type; otherwise
        returns `type` itself. Idempotent.
        
        ```
            wrap(int.class) == Integer.class
            wrap(Integer.class) == Integer.class
            wrap(String.class) == String.class
        ```
        """
        ...


    @staticmethod
    def unwrap(type: type["T"]) -> type["T"]:
        """
        Returns the corresponding primitive type of `type` if it is a wrapper type; otherwise
        returns `type` itself. Idempotent.
        
        ```
            unwrap(Integer.class) == int.class
            unwrap(int.class) == int.class
            unwrap(String.class) == String.class
        ```
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.RegularImmutableAsList

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.util.function import Consumer
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class RegularImmutableAsList(ImmutableAsList):
    """
    An ImmutableAsList implementation specialized for when the delegate collection is already
    backed by an `ImmutableList` or array.

    Author(s)
    - Louis Wasserman
    """

    def listIterator(self, index: int) -> "UnmodifiableListIterator"["E"]:
        ...


    def forEach(self, action: "Consumer"["E"]) -> None:
        ...


    def get(self, index: int) -> "E":
        ...



"""
Python module generated from Java source file org.bukkit.entity.Animals

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import UUID
from org.bukkit import Material
from org.bukkit.entity import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class Animals(Breedable):
    """
    Represents an Animal.
    """

    def getBreedCause(self) -> "UUID":
        """
        Get the UUID of the entity that caused this entity to enter the
        .canBreed() state.

        Returns
        - uuid if set, or null
        """
        ...


    def setBreedCause(self, uuid: "UUID") -> None:
        """
        Set the UUID of the entity that caused this entity to enter the
        .canBreed() state.

        Arguments
        - uuid: new uuid, or null
        """
        ...


    def isLoveMode(self) -> bool:
        """
        Get whether or not this entity is in love mode and will produce
        offspring with another entity in love mode. Will return True if
        and only if .getLoveModeTicks() is greater than 0.

        Returns
        - True if in love mode, False otherwise
        """
        ...


    def getLoveModeTicks(self) -> int:
        """
        Get the amount of ticks remaining for this entity in love mode.
        If the entity is not in love mode, 0 will be returned.

        Returns
        - the remaining love mode ticks
        """
        ...


    def setLoveModeTicks(self, ticks: int) -> None:
        """
        Set the amount of ticks for which this entity should be in love mode.
        Setting the love mode ticks to 600 is the equivalent of a player
        feeding the entity their breeding item of choice.

        Arguments
        - ticks: the love mode ticks. Must be positive
        """
        ...


    def isBreedItem(self, stack: "ItemStack") -> bool:
        """
        Check if the provided ItemStack is the correct item used for breeding
        this entity.

        Arguments
        - stack: ItemStack to check.

        Returns
        - if the provided ItemStack is the correct food item for this
        entity.
        """
        ...


    def isBreedItem(self, material: "Material") -> bool:
        """
        Check if the provided ItemStack is the correct item used for breeding
        this entity..

        Arguments
        - material: Material to check.

        Returns
        - if the provided ItemStack is the correct food item for this
        entity.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.HashBiMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import Objects
from com.google.common.collect import *
from com.google.common.collect.Maps import IteratorBasedAbstractMap
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import RetainedWith
from com.google.j2objc.annotations import Weak
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.io import Serializable
from java.util import Arrays
from java.util import ConcurrentModificationException
from java.util import Iterator
from java.util import NoSuchElementException
from java.util.function import BiConsumer
from java.util.function import BiFunction
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class HashBiMap(IteratorBasedAbstractMap, BiMap, Serializable):
    """
    A BiMap backed by two hash tables. This implementation allows null keys and values. A
    `HashBiMap` and its inverse are both serializable.
    
    This implementation guarantees insertion-based iteration order of its keys.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#bimap">`BiMap` </a>.

    Author(s)
    - Mike Bostock

    Since
    - 2.0
    """

    @staticmethod
    def create() -> "HashBiMap"["K", "V"]:
        """
        Returns a new, empty `HashBiMap` with the default initial capacity (16).
        """
        ...


    @staticmethod
    def create(expectedSize: int) -> "HashBiMap"["K", "V"]:
        """
        Constructs a new, empty bimap with the specified expected size.

        Arguments
        - expectedSize: the expected number of entries

        Raises
        - IllegalArgumentException: if the specified expected size is negative
        """
        ...


    @staticmethod
    def create(map: dict["K", "V"]) -> "HashBiMap"["K", "V"]:
        """
        Constructs a new bimap containing initial values from `map`. The bimap is created with an
        initial capacity sufficient to hold the mappings in the specified map.
        """
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def containsValue(self, value: "Object") -> bool:
        """
        Returns `True` if this BiMap contains an entry whose value is equal to `value` (or,
        equivalently, if this inverse view contains a key that is equal to `value`).
        
        Due to the property that values in a BiMap are unique, this will tend to execute in
        faster-than-linear time.

        Arguments
        - value: the object to search for in the values of this BiMap

        Returns
        - True if a mapping exists from a key to the specified value
        """
        ...


    def get(self, key: "Object") -> "V":
        ...


    def put(self, key: "K", value: "V") -> "V":
        ...


    def forcePut(self, key: "K", value: "V") -> "V":
        ...


    def remove(self, key: "Object") -> "V":
        ...


    def clear(self) -> None:
        ...


    def size(self) -> int:
        ...


    def keySet(self) -> set["K"]:
        ...


    def values(self) -> set["V"]:
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        ...


    def replaceAll(self, function: "BiFunction"["K", "V", "V"]) -> None:
        ...


    def inverse(self) -> "BiMap"["V", "K"]:
        ...



"""
Python module generated from Java source file org.bukkit.event.block.CampfireStartEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from org.bukkit.inventory import CampfireRecipe
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class CampfireStartEvent(InventoryBlockStartEvent):
    """
    Called when a Campfire starts to cook.
    """

    def __init__(self, furnace: "Block", source: "ItemStack", recipe: "CampfireRecipe"):
        ...


    def getRecipe(self) -> "CampfireRecipe":
        """
        Gets the CampfireRecipe associated with this event.

        Returns
        - the CampfireRecipe being cooked
        """
        ...


    def getTotalCookTime(self) -> int:
        """
        Gets the total cook time associated with this event.

        Returns
        - the total cook time
        """
        ...


    def setTotalCookTime(self, cookTime: int) -> None:
        """
        Sets the total cook time for this event.

        Arguments
        - cookTime: the new total cook time
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.inventory.view.CrafterView

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory import CrafterInventory
from org.bukkit.inventory import InventoryView
from org.bukkit.inventory.view import *
from typing import Any, Callable, Iterable, Tuple


class CrafterView(InventoryView):
    """
    An instance of InventoryView which provides extra methods related to
    crafter view data.
    """

    def getTopInventory(self) -> "CrafterInventory":
        ...


    def isSlotDisabled(self, slot: int) -> bool:
        """
        Checks if the given crafter slot is disabled.

        Arguments
        - slot: the slot to check

        Returns
        - True if the slot is disabled otherwise False
        """
        ...


    def isPowered(self) -> bool:
        """
        Checks whether or not this crafter view is powered.

        Returns
        - True if the crafter is powered
        """
        ...


    def setSlotDisabled(self, slot: int, disabled: bool) -> None:
        """
        Sets the status of the crafter slot.

        Arguments
        - slot: the slot to set the status of
        - disabled: True if the slot should be disabled otherwise False
        """
        ...



"""
Python module generated from Java source file com.google.common.hash.HashingInputStream

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.hash import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import FilterInputStream
from java.io import IOException
from java.io import InputStream
from typing import Any, Callable, Iterable, Tuple


class HashingInputStream(FilterInputStream):
    """
    An InputStream that maintains a hash of the data read from it.

    Author(s)
    - Qian Huang

    Since
    - 16.0
    """

    def __init__(self, hashFunction: "HashFunction", in: "InputStream"):
        """
        Creates an input stream that hashes using the given HashFunction and delegates all data
        read from it to the underlying InputStream.
        
        The InputStream should not be read from before or after the hand-off.
        """
        ...


    def read(self) -> int:
        """
        Reads the next byte of data from the underlying input stream and updates the hasher with the
        byte read.
        """
        ...


    def read(self, bytes: list[int], off: int, len: int) -> int:
        """
        Reads the specified bytes of data from the underlying input stream and updates the hasher with
        the bytes read.
        """
        ...


    def markSupported(self) -> bool:
        """
        mark() is not supported for HashingInputStream

        Returns
        - `False` always
        """
        ...


    def mark(self, readlimit: int) -> None:
        """
        mark() is not supported for HashingInputStream
        """
        ...


    def reset(self) -> None:
        """
        reset() is not supported for HashingInputStream.

        Raises
        - IOException: this operation is not supported
        """
        ...


    def hash(self) -> "HashCode":
        """
        Returns the HashCode based on the data read from this stream. The result is unspecified
        if this method is called more than once on the same instance.
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Farmland

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import BlockData
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Farmland(BlockData):
    """
    The 'moisture' level of farmland indicates how close it is to a water source
    (if any).
    
    A higher moisture level leads, to faster growth of crops on this block, but
    cannot be higher than .getMaximumMoisture().
    """

    def getMoisture(self) -> int:
        """
        Gets the value of the 'moisture' property.

        Returns
        - the 'moisture' value
        """
        ...


    def setMoisture(self, moisture: int) -> None:
        """
        Sets the value of the 'moisture' property.

        Arguments
        - moisture: the new 'moisture' value
        """
        ...


    def getMaximumMoisture(self) -> int:
        """
        Gets the maximum allowed value of the 'moisture' property.

        Returns
        - the maximum 'moisture' value
        """
        ...



"""
Python module generated from Java source file com.google.common.base.internal.Finalizer

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base.internal import *
from java.lang.ref import PhantomReference
from java.lang.ref import Reference
from java.lang.ref import ReferenceQueue
from java.lang.ref import WeakReference
from java.lang.reflect import Constructor
from java.lang.reflect import Field
from java.lang.reflect import Method
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Finalizer(Runnable):

    @staticmethod
    def startFinalizer(finalizableReferenceClass: type[Any], queue: "ReferenceQueue"["Object"], frqReference: "PhantomReference"["Object"]) -> None:
        """
        Starts the Finalizer thread. FinalizableReferenceQueue calls this method reflectively.

        Arguments
        - finalizableReferenceClass: FinalizableReference.class.
        - queue: a reference queue that the thread will poll.
        - frqReference: a phantom reference to the FinalizableReferenceQueue, which will be queued
            either when the FinalizableReferenceQueue is no longer referenced anywhere, or when its
            close() method is called.
        """
        ...


    def run(self) -> None:
        """
        Loops continuously, pulling references off the queue and cleaning them up.
        """
        ...



"""
Python module generated from Java source file com.google.common.base.StandardSystemProperty

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import *
from enum import Enum
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class StandardSystemProperty(Enum):
    """
    Represents a System.getProperties() standard system property.

    Author(s)
    - Kurt Alfred Kluever

    Since
    - 15.0
    """

    JAVA_VERSION = ("java.version")
    """
    Java Runtime Environment version.
    """
    JAVA_VENDOR = ("java.vendor")
    """
    Java Runtime Environment vendor.
    """
    JAVA_VENDOR_URL = ("java.vendor.url")
    """
    Java vendor URL.
    """
    JAVA_HOME = ("java.home")
    """
    Java installation directory.
    """
    JAVA_VM_SPECIFICATION_VERSION = ("java.vm.specification.version")
    """
    Java Virtual Machine specification version.
    """
    JAVA_VM_SPECIFICATION_VENDOR = ("java.vm.specification.vendor")
    """
    Java Virtual Machine specification vendor.
    """
    JAVA_VM_SPECIFICATION_NAME = ("java.vm.specification.name")
    """
    Java Virtual Machine specification name.
    """
    JAVA_VM_VERSION = ("java.vm.version")
    """
    Java Virtual Machine implementation version.
    """
    JAVA_VM_VENDOR = ("java.vm.vendor")
    """
    Java Virtual Machine implementation vendor.
    """
    JAVA_VM_NAME = ("java.vm.name")
    """
    Java Virtual Machine implementation name.
    """
    JAVA_SPECIFICATION_VERSION = ("java.specification.version")
    """
    Java Runtime Environment specification version.
    """
    JAVA_SPECIFICATION_VENDOR = ("java.specification.vendor")
    """
    Java Runtime Environment specification vendor.
    """
    JAVA_SPECIFICATION_NAME = ("java.specification.name")
    """
    Java Runtime Environment specification name.
    """
    JAVA_CLASS_VERSION = ("java.class.version")
    """
    Java class format version number.
    """
    JAVA_CLASS_PATH = ("java.class.path")
    """
    Java class path.
    """
    JAVA_LIBRARY_PATH = ("java.library.path")
    """
    List of paths to search when loading libraries.
    """
    JAVA_IO_TMPDIR = ("java.io.tmpdir")
    """
    Default temp file path.
    """
    JAVA_COMPILER = ("java.compiler")
    """
    Name of JIT compiler to use.
    """
    JAVA_EXT_DIRS = ("java.ext.dirs")
    """
    Path of extension directory or directories.

    Deprecated
    - This property was <a
        href="https://openjdk.java.net/jeps/220#Removed:-The-extension-mechanism">deprecated</a> in
        Java 8 and removed in Java 9. We do not plan to remove this API from Guava, but if you are
        using it, it is probably not doing what you want.
    """
    OS_NAME = ("os.name")
    """
    Operating system name.
    """
    OS_ARCH = ("os.arch")
    """
    Operating system architecture.
    """
    OS_VERSION = ("os.version")
    """
    Operating system version.
    """
    FILE_SEPARATOR = ("file.separator")
    """
    File separator ("/" on UNIX).
    """
    PATH_SEPARATOR = ("path.separator")
    """
    Path separator (":" on UNIX).
    """
    LINE_SEPARATOR = ("line.separator")
    """
    Line separator ("\n" on UNIX).
    """
    USER_NAME = ("user.name")
    """
    User's account name.
    """
    USER_HOME = ("user.home")
    """
    User's home directory.
    """
    USER_DIR = ("user.dir")
    """
    User's current working directory.
    """


    def key(self) -> str:
        """
        Returns the key used to look up this system property.
        """
        ...


    def value(self) -> str:
        """
        Returns the current value for this system property by delegating to System.getProperty(String).
        
        The value returned by this method is non-null except in rare circumstances:
        
        
          - .JAVA_EXT_DIRS was deprecated in Java 8 and removed in Java 9. We have not
              confirmed whether it is available under older versions.
          - .JAVA_COMPILER, while still listed as required as of Java 15, is typically not
              available even under older version.
          - Any property may be cleared through APIs like System.clearProperty.
          - Unusual environments like GWT may have their own special handling of system properties.
        
        
        Note that `StandardSystemProperty` does not provide constants for more recently added
        properties, including:
        
        
          - `java.vendor.version` (added in Java 11, listed as optional as of Java 13)
          - `jdk.module.*` (added in Java 9, optional)
        """
        ...


    def toString(self) -> str:
        """
        Returns a string representation of this system property.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerBedEnterEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import World
from org.bukkit.block import Block
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerBedEnterEvent(PlayerEvent, Cancellable):
    """
    This event is fired when the player is almost about to enter the bed.
    """

    def __init__(self, who: "Player", bed: "Block", bedEnterResult: "BedEnterResult"):
        ...


    def __init__(self, who: "Player", bed: "Block"):
        ...


    def getBedEnterResult(self) -> "BedEnterResult":
        """
        This describes the default outcome of this event.

        Returns
        - the bed enter result representing the default outcome of this event
        """
        ...


    def useBed(self) -> "Result":
        """
        This controls the action to take with the bed that was clicked on.
        
        In case of org.bukkit.event.Event.Result.DEFAULT, the default outcome is described by
        .getBedEnterResult().

        Returns
        - the action to take with the interacted bed

        See
        - .setUseBed(org.bukkit.event.Event.Result)
        """
        ...


    def setUseBed(self, useBed: "Result") -> None:
        """
        Sets the action to take with the interacted bed.
        
        org.bukkit.event.Event.Result.ALLOW will result in the player sleeping, regardless of
        the default outcome described by .getBedEnterResult().
        
        org.bukkit.event.Event.Result.DENY will prevent the player from sleeping. This has the
        same effect as canceling the event via .setCancelled(boolean).
        
        org.bukkit.event.Event.Result.DEFAULT will result in the outcome described by
        .getBedEnterResult().

        Arguments
        - useBed: the action to take with the interacted bed

        See
        - .useBed()
        """
        ...


    def isCancelled(self) -> bool:
        """
        Gets the cancellation state of this event. Set to True if you want to
        prevent the player from sleeping.
        
        Canceling the event has the same effect as setting .useBed() to
        org.bukkit.event.Event.Result.DENY.
        
        For backwards compatibility reasons this also returns True if
        .useBed() is org.bukkit.event.Event.Result.DEFAULT and the
        .getBedEnterResult() default action is to prevent bed entering.

        Returns
        - boolean cancellation state
        """
        ...


    def setCancelled(self, cancel: bool) -> None:
        """
        Sets the cancellation state of this event. A canceled event will not be
        executed in the server, but will still pass to other plugins.
        
        Canceling this event will prevent use of the bed.

        Arguments
        - cancel: True if you wish to cancel this event
        """
        ...


    def getBed(self) -> "Block":
        """
        Returns the bed block involved in this event.

        Returns
        - the bed block involved in this event
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class BedEnterResult(Enum):
        """
        Represents the default possible outcomes of this event.
        """

        OK = 0
        """
        The player will enter the bed.
        """
        NOT_POSSIBLE_HERE = 1
        """
        The world doesn't allow sleeping or saving the spawn point (eg,
        Nether, The End or Custom Worlds). This is based on
        World.isBedWorks() and World.isNatural().
        
        Entering the bed is prevented and if World.isBedWorks() is
        False then the bed explodes.
        """
        NOT_POSSIBLE_NOW = 2
        """
        Entering the bed is prevented due to it not being night nor
        thundering currently.
        
        If the event is forcefully allowed during daytime, the player will
        enter the bed (and set its bed location), but might get immediately
        thrown out again.
        """
        TOO_FAR_AWAY = 3
        """
        Entering the bed is prevented due to the player being too far away.
        """
        NOT_SAFE = 4
        """
        Entering the bed is prevented due to there being monsters nearby.
        """
        OTHER_PROBLEM = 5
        """
        Entering the bed is prevented due to there being some other problem.
        """



"""
Python module generated from Java source file org.bukkit.entity.IronGolem

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class IronGolem(Golem):
    """
    An iron Golem that protects Villages.
    """

    def isPlayerCreated(self) -> bool:
        """
        Gets whether this iron golem was built by a player.

        Returns
        - Whether this iron golem was built by a player
        """
        ...


    def setPlayerCreated(self, playerCreated: bool) -> None:
        """
        Sets whether this iron golem was built by a player or not.

        Arguments
        - playerCreated: True if you want to set the iron golem as being
            player created, False if you want it to be a natural village golem.
        """
        ...



"""
Python module generated from Java source file net.md_5.bungee.api.chat.hover.content.Text

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Arrays
from net.md_5.bungee.api.chat import BaseComponent
from net.md_5.bungee.api.chat import HoverEvent
from net.md_5.bungee.api.chat.hover.content import *
from typing import Any, Callable, Iterable, Tuple


class Text(Content):

    def __init__(self, value: list["BaseComponent"]):
        ...


    def __init__(self, value: "BaseComponent"):
        ...


    def __init__(self, value: str):
        ...


    def requiredAction(self) -> "HoverEvent.Action":
        ...


    def equals(self, o: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...



"""
Python module generated from Java source file java.io.InputStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.util import Arrays
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class InputStream(Closeable):
    """
    This abstract class is the superclass of all classes representing
    an input stream of bytes.
    
     Applications that need to define a subclass of `InputStream`
    must always provide a method that returns the next byte of input.

    Author(s)
    - Arthur van Hoff

    See
    - java.io.PushbackInputStream

    Since
    - 1.0
    """

    def __init__(self):
        """
        Constructor for subclasses to call.
        """
        ...


    @staticmethod
    def nullInputStream() -> "InputStream":
        """
        Returns a new `InputStream` that reads no bytes. The returned
        stream is initially open.  The stream is closed by calling the
        `close()` method.  Subsequent calls to `close()` have no
        effect.
        
         While the stream is open, the `available()`, `read()`,
        `read(byte[])`, `read(byte[], int, int)`,
        `readAllBytes()`, `readNBytes(byte[], int, int)`,
        `readNBytes(int)`, `skip(long)`, `skipNBytes(long)`,
        and `transferTo()` methods all behave as if end of stream has been
        reached.  After the stream has been closed, these methods all throw
        `IOException`.
        
         The `markSupported()` method returns `False`.  The
        `mark()` method does nothing, and the `reset()` method
        throws `IOException`.

        Returns
        - an `InputStream` which contains no bytes

        Since
        - 11
        """
        ...


    def read(self) -> int:
        """
        Reads the next byte of data from the input stream. The value byte is
        returned as an `int` in the range `0` to
        `255`. If no byte is available because the end of the stream
        has been reached, the value `-1` is returned. This method
        blocks until input data is available, the end of the stream is detected,
        or an exception is thrown.
        
         A subclass must provide an implementation of this method.

        Returns
        - the next byte of data, or `-1` if the end of the
                    stream is reached.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def read(self, b: list[int]) -> int:
        """
        Reads some number of bytes from the input stream and stores them into
        the buffer array `b`. The number of bytes actually read is
        returned as an integer.  This method blocks until input data is
        available, end of file is detected, or an exception is thrown.
        
         If the length of `b` is zero, then no bytes are read and
        `0` is returned; otherwise, there is an attempt to read at
        least one byte. If no byte is available because the stream is at the
        end of the file, the value `-1` is returned; otherwise, at
        least one byte is read and stored into `b`.
        
         The first byte read is stored into element `b[0]`, the
        next one into `b[1]`, and so on. The number of bytes read is,
        at most, equal to the length of `b`. Let *k* be the
        number of bytes actually read; these bytes will be stored in elements
        `b[0]` through `b[`*k*`-1]`,
        leaving elements `b[`*k*`]` through
        `b[b.length-1]` unaffected.
        
         The `read(b)` method for class `InputStream`
        has the same effect as: ````read(b, 0, b.length)````

        Arguments
        - b: the buffer into which the data is read.

        Returns
        - the total number of bytes read into the buffer, or
                    `-1` if there is no more data because the end of
                    the stream has been reached.

        Raises
        - IOException: If the first byte cannot be read for any reason
                    other than the end of the file, if the input stream has been
                    closed, or if some other I/O error occurs.
        - NullPointerException: if `b` is `null`.

        See
        - java.io.InputStream.read(byte[], int, int)
        """
        ...


    def read(self, b: list[int], off: int, len: int) -> int:
        """
        Reads up to `len` bytes of data from the input stream into
        an array of bytes.  An attempt is made to read as many as
        `len` bytes, but a smaller number may be read.
        The number of bytes actually read is returned as an integer.
        
         This method blocks until input data is available, end of file is
        detected, or an exception is thrown.
        
         If `len` is zero, then no bytes are read and
        `0` is returned; otherwise, there is an attempt to read at
        least one byte. If no byte is available because the stream is at end of
        file, the value `-1` is returned; otherwise, at least one
        byte is read and stored into `b`.
        
         The first byte read is stored into element `b[off]`, the
        next one into `b[off+1]`, and so on. The number of bytes read
        is, at most, equal to `len`. Let *k* be the number of
        bytes actually read; these bytes will be stored in elements
        `b[off]` through `b[off+`*k*`-1]`,
        leaving elements `b[off+`*k*`]` through
        `b[off+len-1]` unaffected.
        
         In every case, elements `b[0]` through
        `b[off-1]` and elements `b[off+len]` through
        `b[b.length-1]` are unaffected.
        
         The `read(b, off, len)` method
        for class `InputStream` simply calls the method
        `read()` repeatedly. If the first such call results in an
        `IOException`, that exception is returned from the call to
        the `read(b,` `off,` `len)` method.  If
        any subsequent call to `read()` results in a
        `IOException`, the exception is caught and treated as if it
        were end of file; the bytes read up to that point are stored into
        `b` and the number of bytes read before the exception
        occurred is returned. The default implementation of this method blocks
        until the requested amount of input data `len` has been read,
        end of file is detected, or an exception is thrown. Subclasses are
        encouraged to provide a more efficient implementation of this method.

        Arguments
        - b: the buffer into which the data is read.
        - off: the start offset in array `b`
                          at which the data is written.
        - len: the maximum number of bytes to read.

        Returns
        - the total number of bytes read into the buffer, or
                    `-1` if there is no more data because the end of
                    the stream has been reached.

        Raises
        - IOException: If the first byte cannot be read for any reason
                    other than end of file, or if the input stream has been closed,
                    or if some other I/O error occurs.
        - NullPointerException: If `b` is `null`.
        - IndexOutOfBoundsException: If `off` is negative,
                    `len` is negative, or `len` is greater than
                    `b.length - off`

        See
        - java.io.InputStream.read()
        """
        ...


    def readAllBytes(self) -> list[int]:
        """
        Reads all remaining bytes from the input stream. This method blocks until
        all remaining bytes have been read and end of stream is detected, or an
        exception is thrown. This method does not close the input stream.
        
         When this stream reaches end of stream, further invocations of this
        method will return an empty byte array.
        
         Note that this method is intended for simple cases where it is
        convenient to read all bytes into a byte array. It is not intended for
        reading input streams with large amounts of data.
        
         The behavior for the case where the input stream is *asynchronously
        closed*, or the thread interrupted during the read, is highly input
        stream specific, and therefore not specified.
        
         If an I/O error occurs reading from the input stream, then it may do
        so after some, but not all, bytes have been read. Consequently the input
        stream may not be at end of stream and may be in an inconsistent state.
        It is strongly recommended that the stream be promptly closed if an I/O
        error occurs.

        Returns
        - a byte array containing the bytes read from this input stream

        Raises
        - IOException: if an I/O error occurs
        - OutOfMemoryError: if an array of the required size cannot be
                allocated.

        Since
        - 9

        Unknown Tags
        - This method invokes .readNBytes(int) with a length of
        Integer.MAX_VALUE.
        """
        ...


    def readNBytes(self, len: int) -> list[int]:
        """
        Reads up to a specified number of bytes from the input stream. This
        method blocks until the requested number of bytes has been read, end
        of stream is detected, or an exception is thrown. This method does not
        close the input stream.
        
         The length of the returned array equals the number of bytes read
        from the stream. If `len` is zero, then no bytes are read and
        an empty byte array is returned. Otherwise, up to `len` bytes
        are read from the stream. Fewer than `len` bytes may be read if
        end of stream is encountered.
        
         When this stream reaches end of stream, further invocations of this
        method will return an empty byte array.
        
         Note that this method is intended for simple cases where it is
        convenient to read the specified number of bytes into a byte array. The
        total amount of memory allocated by this method is proportional to the
        number of bytes read from the stream which is bounded by `len`.
        Therefore, the method may be safely called with very large values of
        `len` provided sufficient memory is available.
        
         The behavior for the case where the input stream is *asynchronously
        closed*, or the thread interrupted during the read, is highly input
        stream specific, and therefore not specified.
        
         If an I/O error occurs reading from the input stream, then it may do
        so after some, but not all, bytes have been read. Consequently the input
        stream may not be at end of stream and may be in an inconsistent state.
        It is strongly recommended that the stream be promptly closed if an I/O
        error occurs.

        Arguments
        - len: the maximum number of bytes to read

        Returns
        - a byte array containing the bytes read from this input stream

        Raises
        - IllegalArgumentException: if `length` is negative
        - IOException: if an I/O error occurs
        - OutOfMemoryError: if an array of the required size cannot be
                allocated.

        Since
        - 11

        Unknown Tags
        - The number of bytes allocated to read data from this stream and return
        the result is bounded by `2*(long)len`, inclusive.
        """
        ...


    def readNBytes(self, b: list[int], off: int, len: int) -> int:
        """
        Reads the requested number of bytes from the input stream into the given
        byte array. This method blocks until `len` bytes of input data have
        been read, end of stream is detected, or an exception is thrown. The
        number of bytes actually read, possibly zero, is returned. This method
        does not close the input stream.
        
         In the case where end of stream is reached before `len` bytes
        have been read, then the actual number of bytes read will be returned.
        When this stream reaches end of stream, further invocations of this
        method will return zero.
        
         If `len` is zero, then no bytes are read and `0` is
        returned; otherwise, there is an attempt to read up to `len` bytes.
        
         The first byte read is stored into element `b[off]`, the next
        one in to `b[off+1]`, and so on. The number of bytes read is, at
        most, equal to `len`. Let *k* be the number of bytes actually
        read; these bytes will be stored in elements `b[off]` through
        `b[off+`*k*`-1]`, leaving elements `b[off+`*k*
        `]` through `b[off+len-1]` unaffected.
        
         The behavior for the case where the input stream is *asynchronously
        closed*, or the thread interrupted during the read, is highly input
        stream specific, and therefore not specified.
        
         If an I/O error occurs reading from the input stream, then it may do
        so after some, but not all, bytes of `b` have been updated with
        data from the input stream. Consequently the input stream and `b`
        may be in an inconsistent state. It is strongly recommended that the
        stream be promptly closed if an I/O error occurs.

        Arguments
        - b: the byte array into which the data is read
        - off: the start offset in `b` at which the data is written
        - len: the maximum number of bytes to read

        Returns
        - the actual number of bytes read into the buffer

        Raises
        - IOException: if an I/O error occurs
        - NullPointerException: if `b` is `null`
        - IndexOutOfBoundsException: If `off` is negative, `len`
                is negative, or `len` is greater than `b.length - off`

        Since
        - 9
        """
        ...


    def skip(self, n: int) -> int:
        """
        Skips over and discards `n` bytes of data from this input
        stream. The `skip` method may, for a variety of reasons, end
        up skipping over some smaller number of bytes, possibly `0`.
        This may result from any of a number of conditions; reaching end of file
        before `n` bytes have been skipped is only one possibility.
        The actual number of bytes skipped is returned. If `n` is
        negative, the `skip` method for class `InputStream` always
        returns 0, and no bytes are skipped. Subclasses may handle the negative
        value differently.
        
         The `skip` method implementation of this class creates a
        byte array and then repeatedly reads into it until `n` bytes
        have been read or the end of the stream has been reached. Subclasses are
        encouraged to provide a more efficient implementation of this method.
        For instance, the implementation may depend on the ability to seek.

        Arguments
        - n: the number of bytes to be skipped.

        Returns
        - the actual number of bytes skipped which might be zero.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.io.InputStream.skipNBytes(long)
        """
        ...


    def skipNBytes(self, n: int) -> None:
        """
        Skips over and discards exactly `n` bytes of data from this input
        stream.  If `n` is zero, then no bytes are skipped.
        If `n` is negative, then no bytes are skipped.
        Subclasses may handle the negative value differently.
        
         This method blocks until the requested number of bytes has been
        skipped, end of file is reached, or an exception is thrown.
        
         If end of stream is reached before the stream is at the desired
        position, then an `EOFException` is thrown.
        
         If an I/O error occurs, then the input stream may be
        in an inconsistent state. It is strongly recommended that the
        stream be promptly closed if an I/O error occurs.

        Arguments
        - n: the number of bytes to be skipped.

        Raises
        - EOFException: if end of stream is encountered before the
                    stream can be positioned `n` bytes beyond its position
                    when this method was invoked.
        - IOException: if the stream cannot be positioned properly or
                    if an I/O error occurs.

        See
        - java.io.InputStream.skip(long)

        Since
        - 12

        Unknown Tags
        - Subclasses are encouraged to provide a more efficient implementation
        of this method.
        - If `n` is zero or negative, then no bytes are skipped.
        If `n` is positive, the default implementation of this method
        invokes .skip(long) skip() repeatedly with its parameter equal
        to the remaining number of bytes to skip until the requested number
        of bytes has been skipped or an error condition occurs.  If at any
        point the return value of `skip()` is negative or greater than the
        remaining number of bytes to be skipped, then an `IOException` is
        thrown.  If `skip()` ever returns zero, then .read() is
        invoked to read a single byte, and if it returns `-1`, then an
        `EOFException` is thrown.  Any exception thrown by `skip()`
        or `read()` will be propagated.
        """
        ...


    def available(self) -> int:
        """
        Returns an estimate of the number of bytes that can be read (or skipped
        over) from this input stream without blocking, which may be 0, or 0 when
        end of stream is detected.  The read might be on the same thread or
        another thread.  A single read or skip of this many bytes will not block,
        but may read or skip fewer bytes.
        
         Note that while some implementations of `InputStream` will
        return the total number of bytes in the stream, many will not.  It is
        never correct to use the return value of this method to allocate
        a buffer intended to hold all data in this stream.
        
         A subclass's implementation of this method may choose to throw an
        IOException if this input stream has been closed by invoking the
        .close() method.
        
         The `available` method of `InputStream` always returns
        `0`.
        
         This method should be overridden by subclasses.

        Returns
        - an estimate of the number of bytes that can be read (or
                    skipped over) from this input stream without blocking or
                    `0` when it reaches the end of the input stream.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def close(self) -> None:
        """
        Closes this input stream and releases any system resources associated
        with the stream.
        
         The `close` method of `InputStream` does
        nothing.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def mark(self, readlimit: int) -> None:
        """
        Marks the current position in this input stream. A subsequent call to
        the `reset` method repositions this stream at the last marked
        position so that subsequent reads re-read the same bytes.
        
         The `readlimit` arguments tells this input stream to
        allow that many bytes to be read before the mark position gets
        invalidated.
        
         The general contract of `mark` is that, if the method
        `markSupported` returns `True`, the stream somehow
        remembers all the bytes read after the call to `mark` and
        stands ready to supply those same bytes again if and whenever the method
        `reset` is called.  However, the stream is not required to
        remember any data at all if more than `readlimit` bytes are
        read from the stream before `reset` is called.
        
         Marking a closed stream should not have any effect on the stream.
        
         The `mark` method of `InputStream` does
        nothing.

        Arguments
        - readlimit: the maximum limit of bytes that can be read before
                             the mark position becomes invalid.

        See
        - java.io.InputStream.reset()
        """
        ...


    def reset(self) -> None:
        """
        Repositions this stream to the position at the time the
        `mark` method was last called on this input stream.
        
         The general contract of `reset` is:
        
        
        -  If the method `markSupported` returns
        `True`, then:
        
            -  If the method `mark` has not been called since
            the stream was created, or the number of bytes read from the stream
            since `mark` was last called is larger than the argument
            to `mark` at that last call, then an
            `IOException` might be thrown.
        
            -  If such an `IOException` is not thrown, then the
            stream is reset to a state such that all the bytes read since the
            most recent call to `mark` (or since the start of the
            file, if `mark` has not been called) will be resupplied
            to subsequent callers of the `read` method, followed by
            any bytes that otherwise would have been the next input data as of
            the time of the call to `reset`. 
        
        -  If the method `markSupported` returns
        `False`, then:
        
            -  The call to `reset` may throw an
            `IOException`.
        
            -  If an `IOException` is not thrown, then the stream
            is reset to a fixed state that depends on the particular type of the
            input stream and how it was created. The bytes that will be supplied
            to subsequent callers of the `read` method depend on the
            particular type of the input stream. 
        
        The method `reset` for class `InputStream`
        does nothing except throw an `IOException`.

        Raises
        - IOException: if this stream has not been marked or if the
                 mark has been invalidated.

        See
        - java.io.IOException
        """
        ...


    def markSupported(self) -> bool:
        """
        Tests if this input stream supports the `mark` and
        `reset` methods. Whether or not `mark` and
        `reset` are supported is an invariant property of a
        particular input stream instance. The `markSupported` method
        of `InputStream` returns `False`.

        Returns
        - `True` if this stream instance supports the mark
                 and reset methods; `False` otherwise.

        See
        - java.io.InputStream.reset()
        """
        ...


    def transferTo(self, out: "OutputStream") -> int:
        """
        Reads all bytes from this input stream and writes the bytes to the
        given output stream in the order that they are read. On return, this
        input stream will be at end of stream. This method does not close either
        stream.
        
        This method may block indefinitely reading from the input stream, or
        writing to the output stream. The behavior for the case where the input
        and/or output stream is *asynchronously closed*, or the thread
        interrupted during the transfer, is highly input and output stream
        specific, and therefore not specified.
        
        If an I/O error occurs reading from the input stream or writing to the
        output stream, then it may do so after some bytes have been read or
        written. Consequently the input stream may not be at end of stream and
        one, or both, streams may be in an inconsistent state. It is strongly
        recommended that both streams be promptly closed if an I/O error occurs.

        Arguments
        - out: the output stream, non-null

        Returns
        - the number of bytes transferred

        Raises
        - IOException: if an I/O error occurs when reading or writing
        - NullPointerException: if `out` is `null`

        Since
        - 9
        """
        ...



from .BlockSupport import BlockSupport
from .Conduit import Conduit
from .Vault import Vault
from .Comparator import Comparator
from .Lidded import Lidded
from .SculkSensor import SculkSensor
from .DoubleChest import DoubleChest
from .Campfire import Campfire
from .Crafter import Crafter
from .Lectern import Lectern
from .Sign import Sign
from .DaylightDetector import DaylightDetector
from .Hopper import Hopper
from .BrushableBlock import BrushableBlock
from .Structure import Structure
from .Beehive import Beehive
from .TrialSpawner import TrialSpawner
from .Skull import Skull
from .CreakingHeart import CreakingHeart
from .BlockFace import BlockFace
from .CreatureSpawner import CreatureSpawner
from .Jigsaw import Jigsaw
from .PistonMoveReaction import PistonMoveReaction
from .SuspiciousSand import SuspiciousSand
from .Smoker import Smoker
from .DecoratedPot import DecoratedPot
from .HangingSign import HangingSign
from .Bell import Bell
from .Chest import Chest
from .Biome import Biome
from .Lockable import Lockable
from .Dropper import Dropper
from .Dispenser import Dispenser
from .TileState import TileState
from .Banner import Banner
from .Furnace import Furnace
from .EnderChest import EnderChest
from .CommandBlock import CommandBlock
from .Barrel import Barrel
from .CalibratedSculkSensor import CalibratedSculkSensor
from .Bed import Bed
from .BlockState import BlockState
from .ShulkerBox import ShulkerBox
from .Block import Block
from .BlastFurnace import BlastFurnace
from .EnchantingTable import EnchantingTable
from .SculkShrieker import SculkShrieker
from .EndGateway import EndGateway
from .Beacon import Beacon
from .BlockType import BlockType
from .Jukebox import Jukebox
from .Container import Container
from .EntityBlockStorage import EntityBlockStorage
from .SculkCatalyst import SculkCatalyst
from .ChiseledBookshelf import ChiseledBookshelf
from .BrewingStand import BrewingStand


"""
Python module generated from Java source file org.yaml.snakeyaml.util.ArrayUtils

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import AbstractList
from java.util import Collections
from org.yaml.snakeyaml.util import *
from typing import Any, Callable, Iterable, Tuple


class ArrayUtils:
    """
    Array manipulation
    """

    @staticmethod
    def toUnmodifiableList(elements: list["E"]) -> list["E"]:
        """
        Returns an unmodifiable `List` backed by the given array. The method doesn't copy the
        array, so the changes to the array will affect the `List` as well.
        
        Type `<E>`: class of the elements in the array

        Arguments
        - elements: - array to convert

        Returns
        - `List` backed by the given array
        """
        ...


    @staticmethod
    def toUnmodifiableCompositeList(array1: list["E"], array2: list["E"]) -> list["E"]:
        """
        Returns an unmodifiable `List` containing the second array appended to the first one. The
        method doesn't copy the arrays, so the changes to the arrays will affect the `List` as
        well.
        
        Type `<E>`: class of the elements in the array

        Arguments
        - array1: - the array to extend
        - array2: - the array to add to the first

        Returns
        - `List` backed by the given arrays
        """
        ...
